@@ -5,6 +5,7 @@ from lark import Lark, Transformer
 from .lin import LinFrame, LinSignal
 from .encoding import ASCIIValue, BCDValue, LinSignalType, LogicalValue, PhysicalValue, ValueConverter
 from .node import LinNode, LinMaster, LinProductId, LinSlave
+from .comment import parseComments
 
 class LDF:
 	def __init__(self):
@@ -17,6 +18,7 @@ class LDF:
 		self.signals: List[LinSignal] = []
 		self.frames: List[LinFrame] = []
 		self.converters: Dict[str, LinSignalType] = {}
+		self.comments: List[str] = []
 
 	def signal(self, name: str) -> LinSignal:
 		"""
@@ -40,15 +42,18 @@ class LDF:
 		"""
 		return next((x for x in self.slaves if x.name == name), None)
 
-def parseLDFtoDict(path: str) -> Dict[str, Any]:
+def parseLDFtoDict(path: str, captureComments: bool = False) -> Dict[str, Any]:
 	lark = os.path.join(os.path.dirname(__file__), 'ldf.lark')
 	parser = Lark(grammar=open(lark), parser='lalr')
 	ldf_file = open(path, "r").read()
 	tree = parser.parse(ldf_file)
-	return LDFTransformer().transform(tree)
+	json = LDFTransformer().transform(tree)
+	if captureComments:
+		json['comments'] = parseComments(ldf_file)
+	return json
 
-def parseLDF(path: str) -> LDF:
-	json = parseLDFtoDict(path)
+def parseLDF(path: str, captureComments: bool = False) -> LDF:
+	json = parseLDFtoDict(path, captureComments)
 	ldf = LDF()
 
 	_populate_ldf_header(json, ldf)
@@ -56,6 +61,10 @@ def parseLDF(path: str) -> LDF:
 	_populate_ldf_frames(json, ldf)
 	_populate_ldf_nodes(json, ldf)
 	_populate_ldf_encoding_types(json, ldf)
+
+	if captureComments:
+		ldf.comments = json['comments']
+
 	return ldf
 
 def _populate_ldf_header(json: dict, ldf: LDF):
